@@ -7,7 +7,8 @@ that is extending the :class:`~ae.db_core.DbBase` of the module
 :mod:`ae.db_core` for to connect to an Oracle database.
 
 .. hint::
-  This namespace portion is using the :mod:`cx_Oracle` package
+  This namespace portion is using the
+  `cx_Oracle package <https://cx-oracle.readthedocs.io/en/7.2/module.html>`_
   as the database driver. The cx_Oracle package has to have
   at least version 5 or higher.
 
@@ -18,26 +19,26 @@ basic usage of the oracle database layer
 For to create an instance of the class :class:`OraDb` you
 first have to create a :class:`~ae.sys_core.SystemBase` instance.
 This can be done either programmatically by providing an
-application instance (of the class :class:`~ae.ae_console.ConsoleApp`
+application instance (of the class :class:`~ae.console.ConsoleApp`
 or an inherited sub-class of it) plus any database parameters, like
-required credentials and any database configuration features/options:
+required credentials and any database configuration features/options::
 
     app = ConsoleApp()
     system = SystemBase('system-id', app, dict(User='user name', Password='password`, ...), ...)
 
 Alternatively provide all system-specific info
 within the :ref:`ae config files<config-files>`
-and let :class:`~ae.sys_core.UsedSystems` load it:
+and let :class:`~ae.sys_core.UsedSystems` load it::
 
     system = used_systems['system-id']
 
 Finally pass the database parameters in `system`
-for to create an instance of :class:`OraDb`:
+for to create an instance of :class:`OraDb`::
 
     ora_db = OraDb(system)
 
 Then call the :meth:`~OraDb.connect` method of this
-instance for to connect to the Oracle database server:
+instance for to connect to the Oracle database server::
 
     error_message = ora_db.connect()
     if error_message:
@@ -48,7 +49,7 @@ If the connection could not be established then
 message string. If the return value is an empty
 string then you can use all the methods provided by
 :class:`~ae.db_core.DbBase`, like e.g.
-:meth:`~ae.db_core.DbBase.update`:
+:meth:`~ae.db_core.DbBase.update`::
 
     error_message = ora_db.update('my_table`, {'my_col': 'new value'})
     if error_message:
@@ -58,7 +59,7 @@ string then you can use all the methods provided by
 An explicit call of :meth:`~ae.db_core.DbBase.rollback`
 is only needed if you use transactions.
 In this case you should also use :meth:`~ae.db_core.DbBase.commit`
-at the end of each transaction for to store any data updates:
+at the end of each transaction for to store any data updates::
 
     error_message = ora_db.commit()
 
@@ -67,13 +68,13 @@ that is provided by the :class:`~ae.db_core.DbBase`
 DML methods: by passing a `True` value to this
 argument, the method will automatically execute a
 :meth:`~ae.db_core.DbBase.commit` call for you
-if no error occurred in the DML method:
+if no error occurred in the DML method::
 
     error_message = ora_db.update('table`, {'column': 369}, commit=True)
 
 Finally after all database actions are done you
 can close the connection to the databases server
-with the :meth:`~ae.db_core.DbBase.close` method:
+with the :meth:`~ae.db_core.DbBase.close` method::
 
     error_message = ora_db.close()
 
@@ -87,7 +88,7 @@ import cx_Oracle                                    # type: ignore
 from ae.db_core import DbBase, SystemBase           # type: ignore  # SystemBase is an indirect import from ae.sys_core
 
 
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 
 
 class OraDb(DbBase):
